###########################
django_seleniumhelpers
###########################

Extends ``django.test.LiveServerTestCase`` to simplify selenium webdriver testing.

Docs are available here: https://django_seleniumhelpers.readthedocs.org/en/latest/
